==================
Step Miscellaneous
==================

Miscellaneous Step commands are used for configuring controls, damping, and frequency tables.

Classes
-------

CompositeDamping
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.CompositeDamping.CompositeDamping
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

CompositeDampingComponent
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.CompositeDampingComponent.CompositeDampingComponent
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

CompositeDampingComponentArray
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.CompositeDampingComponentArray.CompositeDampingComponentArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

Control
~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.Control.Control
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

DirectDamping
~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.DirectDamping.DirectDamping
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

DirectDampingByFrequency
~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.DirectDampingByFrequency.DirectDampingByFrequency
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

DirectDampingByFrequencyComponent
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.DirectDampingByFrequencyComponent.DirectDampingByFrequencyComponent
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

DirectDampingByFrequencyComponentArray
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.DirectDampingByFrequencyComponentArray.DirectDampingByFrequencyComponentArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

DirectDampingComponent
~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.DirectDampingComponent.DirectDampingComponent
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

DirectDampingComponentArray
~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.DirectDampingComponentArray.DirectDampingComponentArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

EmagTimeHarmonicFrequency
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.EmagTimeHarmonicFrequency.EmagTimeHarmonicFrequency
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

EmagTimeHarmonicFrequencyArray
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.EmagTimeHarmonicFrequencyArray.EmagTimeHarmonicFrequencyArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

MassScaling
~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.MassScaling.MassScaling
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

MassScalingArray
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.MassScalingArray.MassScalingArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

RandomResponseFrequency
~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.RandomResponseFrequency.RandomResponseFrequency
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

RandomResponseFrequencyArray
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.RandomResponseFrequencyArray.RandomResponseFrequencyArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

RayleighDamping
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.RayleighDamping.RayleighDamping
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

RayleighDampingByFrequency
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.RayleighDampingByFrequency.RayleighDampingByFrequency
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

RayleighDampingByFrequencyComponent
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.RayleighDampingByFrequencyComponent.RayleighDampingByFrequencyComponent
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

RayleighDampingByFrequencyComponentArray
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.RayleighDampingByFrequencyComponentArray.RayleighDampingByFrequencyComponentArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

RayleighDampingComponent
~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.RayleighDampingComponent.RayleighDampingComponent
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

RayleighDampingComponentArray
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.RayleighDampingComponentArray.RayleighDampingComponentArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

ResponseSpectrumComponent
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.ResponseSpectrumComponent.ResponseSpectrumComponent
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

ResponseSpectrumComponentArray
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.ResponseSpectrumComponentArray.ResponseSpectrumComponentArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

SolverControl
~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.SolverControl.SolverControl
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

SteadyStateDirectFrequency
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.SteadyStateDirectFrequency.SteadyStateDirectFrequency
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

SteadyStateDirectFrequencyArray
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.SteadyStateDirectFrequencyArray.SteadyStateDirectFrequencyArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

SteadyStateModalFrequency
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.SteadyStateModalFrequency.SteadyStateModalFrequency
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

SteadyStateModalFrequencyArray
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.SteadyStateModalFrequencyArray.SteadyStateModalFrequencyArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

SteadyStateSubspaceFrequency
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.SteadyStateSubspaceFrequency.SteadyStateSubspaceFrequency
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

SteadyStateSubspaceFrequencyArray
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.SteadyStateSubspaceFrequencyArray.SteadyStateSubspaceFrequencyArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

StructuralDamping
~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.StructuralDamping.StructuralDamping
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

StructuralDampingByFrequency
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.StructuralDampingByFrequency.StructuralDampingByFrequency
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

StructuralDampingByFrequencyComponent
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.StructuralDampingByFrequencyComponent.StructuralDampingByFrequencyComponent
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

StructuralDampingByFrequencyComponentArray
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.StructuralDampingByFrequencyComponentArray.StructuralDampingByFrequencyComponentArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

StructuralDampingComponent
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.StructuralDampingComponent.StructuralDampingComponent
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

StructuralDampingComponentArray
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.StructuralDampingComponentArray.StructuralDampingComponentArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

SubstructureGenerateFrequency
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.SubstructureGenerateFrequency.SubstructureGenerateFrequency
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

SubstructureGenerateFrequencyArray
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.SubstructureGenerateFrequencyArray.SubstructureGenerateFrequencyArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

SubstructureGenerateModes
~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.SubstructureGenerateModes.SubstructureGenerateModes
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

SubstructureGenerateModesArray
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.StepMiscellaneous.SubstructureGenerateModesArray.SubstructureGenerateModesArray
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

